TightFlutterPlatform class abstract

The interface every platform implementation of tight_flutter must honour.

Inheritance
  • Object
  • PlatformInterface
  • TightFlutterPlatform
Implementers

Constructors

TightFlutterPlatform()
Constructs a TightFlutterPlatform.

Properties

events → Stream<TightEvent>
A broadcast stream of native TightEvents (bridged TightDelegate).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBluetoothDevices() → Future<List<TightBluetoothDevice>>
Lists Bluetooth devices known to the SDK.
getCurrentDrive() → Future<TightDrive?>
Reads the current (or most recent) drive, if any.
getMileageDetectionMode() → Future<MileageDetectionMode>
Reads the current mileage detection mode.
getMileagePermissions() → Future<TightPermissions>
Reads the current permission state without prompting.
initialize({required String accessToken}) → Future<void>
Initialises the SDK for a user with a backend-minted accessToken.
isSetup() → Future<bool>
Whether the SDK is set up for the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestBluetoothPermissions() → Future<TightPermissions>
Requests the Bluetooth permissions used for automatic drive detection.
requestMileagePermissions() → Future<TightPermissions>
Requests the mileage tracking permissions and returns the resulting permission state.
saveBluetoothDevice(TightBluetoothDevice device) → Future<bool>
Saves device as an automatic drive-detection trigger.
setMileageDetectionMode(MileageDetectionMode mode) → Future<void>
Sets the mileage detection mode.
startSemiAutoDrive() → Future<void>
Starts a semi-automatic drive.
stopDrive() → Future<void>
Stops the current drive.
teardown() → Future<void>
Tears the SDK down (e.g. on logout).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ TightFlutterPlatform
The default instance of TightFlutterPlatform to use.
getter/setter pair